@@ -55,9 +55,15 @@ elif detector.board.RASPBERRY_PI_B_REV2:
 elif board_id == ap_board.BEAGLEBONE_BLACK:
     from adafruit_blinka.board.beaglebone_black import *
 
+elif board_id == ap_board.BEAGLEBONE_POCKETBEAGLE:
+    from adafruit_blinka.board.beaglebone_pocketbeagle import *
+
 elif board_id == ap_board.ORANGE_PI_PC:
     from adafruit_blinka.board.orangepipc import *
 
+elif board_id == ap_board.ORANGE_PI_R1:
+    from adafruit_blinka.board.orangepir1 import *
+
 elif board_id == ap_board.GIANT_BOARD:
     from adafruit_blinka.board.giantboard import *
 
@@ -70,8 +76,11 @@ elif board_id == ap_board.JETSON_TX2:
 elif board_id == ap_board.JETSON_XAVIER:
     from adafruit_blinka.board.jetson_xavier import *
 
-elif board_id == ap_board.JETSON_TXX:
-    from adafruit_blinka.board.jetson_txx import *
+elif board_id == ap_board.JETSON_NANO:
+    from adafruit_blinka.board.jetson_nano import *
+
+elif board_id == ap_board.CORAL_EDGE_TPU_DEV:
+    from adafruit_blinka.board.coral_edge_tpu import *
 
 elif "sphinx" in sys.modules:
     pass
