@@ -24,5 +24,7 @@ elif chip_id == ap_chip.T186:
     from adafruit_blinka.microcontroller.tegra.t186.pin import *
 elif chip_id == ap_chip.T194:
     from adafruit_blinka.microcontroller.tegra.t194.pin import *
+elif chip_id == ap_chip.IMX8MX:
+    from adafruit_blinka.microcontroller.nxp_imx8m.pin import *
 else:
     raise NotImplementedError("Microcontroller not supported: ", chip_id)
